using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using System.Web.Mvc.Ajax;
using EPiServer.Shell.Gadgets;
using EPiServer.Shell.Gadgets.Contracts;
using EPiServer.Shell.UI.Views.Shared;
using MultiFileUploadGadget1.Models;
using EPiServer.Data.Dynamic;


namespace MultiFileUploadGadget1.Controllers
{
    [Gadget()]
   
    public class UploadController : Controller
    {
        //
        // GET: /Upload/
        
        public ActionResult Index(Guid gadgetId)

        {
            var uploaddata = new FileUploadData();
            uploaddata = this.GetViewData(this.LoadSettings(gadgetId));
            uploaddata.GadgetId = gadgetId;
            return View("Index", uploaddata);
        }

        [GadgetAction(ActionType.Menu, TextResourceKey = "Edit", ResourceType = typeof(SharedResources))]
        public ActionResult Configure(Guid gadgetId)
        {
            FileUploadData model = new FileUploadData();
            model.Settings = this.LoadSettings(gadgetId);
            model.GadgetId = gadgetId;

            return View("Configure", model);
        }

        private FileUploadData GetViewData(UploadSettings settings)
        {
            FileUploadData data = new FileUploadData();
            data.Settings = settings;
           
            return data;
        }


        public ActionResult SaveSettings(UploadSettings settings, Guid gadgetId)
        {
            this.SaveSettings(gadgetId, settings);
            FileUploadData data = new FileUploadData();
            data.Settings = settings;
            data.GadgetId = gadgetId;
            return this.ShowGadget(gadgetId);
        }

        private void SaveSettings(Guid gadgetId, UploadSettings settings)
        {
            UploadSettings settings2 = this.LoadSettings(gadgetId);
            settings2.GadgetID = gadgetId;
            settings2.DefaultFolder = settings.DefaultFolder;
            this.GadgetSettingsStore.Save(settings2);
        }

        public ActionResult ShowGadget(Guid gadgetId)
        {
            UploadSettings settings = this.LoadSettings(gadgetId);
            FileUploadData viewData = this.GetViewData(settings);
            viewData.GadgetId = gadgetId;
            return View("Index", viewData);
        }

 

 

 

 


        private UploadSettings LoadSettings(Guid gadgetId)
        {
            UploadSettings settings = this.GadgetSettingsStore.Find("GadgetId", gadgetId).FirstOrDefault<UploadSettings>();
            if (settings == null)
            {
                settings = new UploadSettings();
            }
            return settings;
        }

        private DynamicDataStore<UploadSettings> _gadgetSettingsStore;

        public DynamicDataStore<UploadSettings> GadgetSettingsStore
        {
            get
            {
                if (this._gadgetSettingsStore == null)
                {
                    this._gadgetSettingsStore = DynamicDataStore<UploadSettings>.CreateStore("FileUploadSettingsStore", false);
                }
                return this._gadgetSettingsStore;
            }
        }
 

 




    }
}
