﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Runtime.Serialization;
using System.ServiceModel;
using System.Text;
using System.IO;
using System.Web.Hosting;
using System.ServiceModel.Activation;
using System.Diagnostics;
using System.Configuration;
using System.Threading;
using EPiServer.Web.Hosting;

/*
 * Copyright Michiel Post
 * http://www.michielpost.nl
 * contact@michielpost.nl
 * */

namespace mpost.FileUploadServiceLibrary
{
    [AspNetCompatibilityRequirements(RequirementsMode=AspNetCompatibilityRequirementsMode.Allowed)]
    public class UploadService : IUploadService
    {
        private string _tempExtension = "_temp";
               
        #region IUploadService Members

        /// <summary>
        /// Cancel the upload and delete the TEMP file
        /// </summary>
        /// <param name="fileName"></param>
        public void CancelUpload(string fileName)
        {
            //string uploadFolder = GetUploadFolder();
            //string tempFileName = fileName + _tempExtension;

            //if (File.Exists(@HostingEnvironment.ApplicationPhysicalPath + "/" + uploadFolder + "/" + tempFileName))
            //    File.Delete(@HostingEnvironment.ApplicationPhysicalPath + "/" + uploadFolder + "/" + tempFileName);

        }


        protected UnifiedDirectory GetUnifiedDirectory(string path)
        {
            UnifiedDirectory directory = HostingEnvironment.VirtualPathProvider.GetDirectory(path) as UnifiedDirectory;
            if (directory == null)
                throw new ArgumentException("Given path is not a Unified Directory");
            return directory;
        }


        /// <summary>
        /// Receive a chunk of data and store it on disk
        /// </summary>
        /// <param name="fileName"></param>
        /// <param name="data"></param>
        /// <param name="dataLength"></param>
        /// <param name="parameters"></param>
        /// <param name="firstChunk"></param>
        /// <param name="lastChunk"></param>
        public void StoreFileAdvanced(string fileName, byte[] data, int dataLength, string parameters, bool firstChunk, bool lastChunk, string foldername)
        {
            string tempFileName = fileName + _tempExtension;
            UnifiedFile uFile;
            UnifiedDirectory dir = GetUnifiedDirectory(foldername);

            if (firstChunk)
            {

                    if (dir is VersioningDirectory)
                    {

                        uFile = (VersioningFile)dir.CreateFile(tempFileName);
                    }

                    else
                    {

                        uFile = (NativeFile)dir.CreateFile(tempFileName);
                    }
            }

            else
            {
                uFile = (UnifiedFile)EPiServer.Web.Hosting.GenericHostingEnvironment.Instance.VirtualPathProvider.GetFile(foldername + tempFileName);
            }

            if (uFile is VersioningFile)
            {
                ((VersioningFile)uFile).CheckOut();
                Stream s = uFile.Open(FileMode.Append);

                s.Write(data, 0, dataLength);

                s.Close();

                ((VersioningFile)uFile).CheckIn(string.Empty);
            }
            else
            {

                Stream s = uFile.Open(FileMode.Append);

                s.Write(data, 0, dataLength);

                s.Close();



            }


            if (lastChunk)
            {
                if (dir is VersioningDirectory)
                {

                    ((VersioningFile)uFile).CheckOut();
                    UnifiedFile.MoveTo(uFile, foldername + fileName);
                    ((VersioningFile)uFile).CheckIn(string.Empty);
                }
                else
                {
                    UnifiedFile.MoveTo(uFile, foldername + fileName);



                }
            }
            FinishedFileUpload(fileName, parameters);
          
        }

        /// <summary>
        /// Delete an uploaded file
        /// </summary>
        /// <param name="fileName"></param>
        protected void DeleteUploadedFile(string fileName)
        {
            string uploadFolder = GetUploadFolder();

            if (File.Exists(@HostingEnvironment.ApplicationPhysicalPath + "/" + uploadFolder + "/" + fileName))
                File.Delete(@HostingEnvironment.ApplicationPhysicalPath + "/" + uploadFolder + "/" + fileName);

        }


        /// <summary>
        /// Do your own stuff here when the file is finished uploading
        /// </summary>
        /// <param name="fileName"></param>
        /// <param name="parameters"></param>
        protected virtual void FinishedFileUpload(string fileName, string parameters)
        {
            //Thread.Sleep(5000);
        }

        /// <summary>
        /// Get the upload folder from the Web.config
        /// You can overwrite this method and always return your custom upload folder
        /// </summary>
        /// <returns></returns>
        protected virtual string GetUploadFolder()
        {           
            string folder = ConfigurationSettings.AppSettings["UploadFolder"];
            if (string.IsNullOrEmpty(folder))
                folder = "Upload";

            return folder;
        }
        
       

        #endregion
    }
}
